@@ -73,7 +73,11 @@ struct MC{F,I}
         y::AbstractVector{F} = F[],
         z::AbstractVector{F} = F[],
     ) where {F<:AbstractFloat,G<:Integer} = begin
-        abs(normal_sign) == 1 || throw(ArgumentError("`normal_sign` should be either -1 or +1"))
+        isa(x, AbstractRange) && (x = collect(x))
+        isa(y, AbstractRange) && (y = collect(y))
+        isa(z, AbstractRange) && (z = collect(z))
+        abs(normal_sign) == 1 ||
+        throw(ArgumentError("`normal_sign` should be either -1 or +1"))
         m = new{F,I}(
             size(vol)...,
             Ref(vol),
@@ -369,7 +373,7 @@ end
     test_interior(case, cb, cfg, subcfg, s)
 
 # Description
-Tests if the components of the tesselation of the cube should be connected through the interior of the cube.
+Tests if the components of the tessellation of the cube should be connected through the interior of the cube.
 """
 test_interior(case, cb::MVector{N,T}, cfg, subcfg, s) where {N,T} = begin
     test = 0
@@ -489,7 +493,7 @@ end
     test_face(cb, face)
 
 # Description
-Tests if the components of the tesselation of the cube should be connected by the interior of an ambiguous face.
+Tests if the components of the tessellation of the cube should be connected by the interior of an ambiguous face.
 """
 test_face(cb::MVector{N,T}, face) where {N,T} = begin
     @inbounds begin
